@@ -5,11 +5,15 @@ __license__ = "MPL 2.0"
 
 import json
 
+import shpc.utils
+
 
 def main(args, parser, extra, subparser):
 
     from shpc.main import get_client
 
+    shpc.utils.ensure_no_extra(extra)
+
     cli = get_client(
         quiet=args.quiet,
         settings_file=args.settings_file,
